/*==============================================================*/
/* Database name:  DATAMODEL_                                   */
/* DBMS name:      PostgreSQL 7                                 */
/* Created on:     6/29/2003 1:40:47 AM                         */
/*==============================================================*/


drop index _refr__fk;

drop index _refr__fk5;

drop index _refr__fk6;

drop index _refr__fk2;

drop index _refr__fk3;

drop index _refr__fk4;

drop table categories;

drop table customers;

drop table goodorders;

drop table goods;

drop table orders;

drop table users;

/*==============================================================*/
/* Table: categories                                            */
/*==============================================================*/
create table categories (
categoryid           serial               not null,
parentid             int4                 null,
categoryname         varchar(100)         not null,
notes                varchar(3000)        null,
constraint pk_categories primary key (categoryid)
);

/*==============================================================*/
/* Index: _refr__fk                                             */
/*==============================================================*/
create  index _refr__fk on categories (
parentid
);

/*==============================================================*/
/* Table: customers                                             */
/*==============================================================*/
create table customers (
customerid           serial               not null,
customername         varchar(20)          not null,
customerfullname     varchar(100)         not null,
tel                  varchar(30)          null,
email                varchar(50)          null,
address              varchar(500)         null,
constraint pk_customers primary key (customerid),
constraint ak_customername_customer unique (customername)
);

/*==============================================================*/
/* Table: goodorders                                            */
/*==============================================================*/
create table goodorders (
orderid              int4                 not null,
goodid               int4                 not null,
goodorderscount      int4                 not null,
baseprice            money                null,
constraint pk_goodorders primary key (orderid, goodid)
);

/*==============================================================*/
/* Index: _refr__fk5                                            */
/*==============================================================*/
create  index _refr__fk5 on goodorders (
orderid
);

/*==============================================================*/
/* Index: _refr__fk6                                            */
/*==============================================================*/
create  index _refr__fk6 on goodorders (
goodid
);

/*==============================================================*/
/* Table: goods                                                 */
/*==============================================================*/
create table goods (
goodid               serial               not null,
categoryid           int4                 not null,
goodname             varchar(100)         not null,
price                money                not null,
goodcount            int4                 not null,
notes                varchar(3000)        null,
constraint pk_goods primary key (goodid)
);

/*==============================================================*/
/* Index: _refr__fk2                                            */
/*==============================================================*/
create  index _refr__fk2 on goods (
categoryid
);

/*==============================================================*/
/* Table: orders                                                */
/*==============================================================*/
create table orders (
orderid              serial               not null,
userid               int4                 null,
customerid           int4                 not null,
discount             decimal(2)           null,
startdate            date                 not null,
enddate              date                 null,
purchase             bool                 not null,
closed               bool                 not null,
notes                varchar(3000)        null,
constraint pk_orders primary key (orderid)
);

/*==============================================================*/
/* Index: _refr__fk3                                            */
/*==============================================================*/
create  index _refr__fk3 on orders (
userid
);

/*==============================================================*/
/* Index: _refr__fk4                                            */
/*==============================================================*/
create  index _refr__fk4 on orders (
customerid
);

/*==============================================================*/
/* Table: users                                                 */
/*==============================================================*/
create table users (
userid               serial               not null,
username             varchar(20)          not null,
userfullname         varchar(100)         not null,
password             char(32)             null,
tel                  varchar(30)          null,
email                varchar(50)          null,
address              varchar(500)         null,
constraint pk_users primary key (userid),
constraint ak_username_users unique (username)
);

alter table categories
   add constraint fk_categori_ischildof_categori foreign key (parentid)
      references categories (categoryid)
      on delete cascade on update cascade;

alter table goodorders
   add constraint fk_goodorde_goodorder_orders foreign key (orderid)
      references orders (orderid)
      on delete cascade on update cascade;

alter table goodorders
   add constraint fk_goodorde_goodorder_goods foreign key (goodid)
      references goods (goodid)
      on delete cascade on update cascade;

alter table goods
   add constraint fk_goods_isincateg_categori foreign key (categoryid)
      references categories (categoryid)
      on delete cascade on update cascade;

alter table orders
   add constraint fk_orders_finalized_users foreign key (userid)
      references users (userid)
      on delete cascade on update cascade;

alter table orders
   add constraint fk_orders_orders_customer foreign key (customerid)
      references customers (customerid)
      on delete cascade on update cascade;

