<xsl:stylesheet
  version="1.0"
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform">

<xsl:output method="text"/> 

<xsl:variable name="pagetype">
    <xsl:value-of select="page/@type"/>
</xsl:variable>

<xsl:variable name="pageaccess">
    <xsl:value-of select="page/@access"/>
</xsl:variable>

<xsl:template match="page">
    <xsl:call-template name="generateheader"/>
    <xsl:call-template name="generateonsuccess"/>
    <xsl:apply-templates select="code"/>
    <xsl:call-template name="generateaccess"/>
    <xsl:call-template name="generateonenter"/>
    <xsl:choose>
        <xsl:when test="$pagetype='view'">
            <xsl:call-template name="generateview"/>
        </xsl:when>
        <xsl:when test="$pagetype='search'">
            <xsl:call-template name="generatesearch"/>
        </xsl:when>
        <xsl:when test="$pagetype='insert'">
            <xsl:call-template name="generateinsert"/>
        </xsl:when>
        <xsl:when test="$pagetype='edit'">
            <xsl:call-template name="generateedit"/>
        </xsl:when>
        <xsl:when test="$pagetype='delete'">
            <xsl:call-template name="generatedelete"/>
        </xsl:when>
        <xsl:otherwise>
            <xsl:call-template name="generateempty"/>
        </xsl:otherwise>
    </xsl:choose>
    <xsl:call-template name="generatefooter"/>
</xsl:template>

<xsl:template name="generateheader">
    <![CDATA[<?php
    if (isset($refresh) && $refresh) {
      header("Location: ../meta/metapage.php?page=$page");
      exit;
    }
    include_once ("../inc/functions.php");
    ]]>
</xsl:template>

<xsl:template name="generatefooter">
    <xsl:variable name="genericscript">
        <xsl:choose>
            <xsl:when test="$pagetype='edit'">insert</xsl:when>
            <xsl:otherwise><xsl:value-of select="$pagetype"/></xsl:otherwise>
        </xsl:choose>
    </xsl:variable>
    <![CDATA[
        require("../basic/]]><xsl:value-of select="$genericscript"/><![CDATA[.php");  
        ?>
    ]]>
</xsl:template>

<xsl:template name="generateempty">
    <![CDATA[
        echo("THE XML DEFINITION DIDN'T CONTAIN A PROPER PAGE ELEMENT<br>\n");
    ]]>
</xsl:template>

<xsl:template name="generateview">
    $title = '<xsl:value-of select="title"/>';
    <xsl:if test="icon">
        $icon = '<xsl:value-of select="icon"/>'; 
    </xsl:if>

    <xsl:if test="top">
        $toptargettable = "<xsl:value-of select="top/targettable"/>";
        $toptargettablepkey = "<xsl:value-of select="top/primarykey"/>";
        $toptargettableakey = "<xsl:value-of select="top/alternatekey"/>";
        $topwhere = "<xsl:value-of select="top/where"/>";
        <xsl:variable name="querydoc" select="document(top/querysource)"/>
        <xsl:variable name="querytext" select="$querydoc/query/querytext"/>
        $topq = '<xsl:value-of select="$querytext"/>';
        <xsl:if test="top/pageparam">
            $topqfilter = "<xsl:value-of select="top/pageparam"/> = ".q($keyid);
          <xsl:if test="top/altparam">
              $topqfilter .= " and <xsl:value-of select="top/altparam"/> = ".q($altid);
          </xsl:if>
        </xsl:if>
        
        $idx = 0;
        <xsl:apply-templates select="top/fields"/>
        $topfieldlen = $idx;
    </xsl:if>

    <xsl:if test="body">
        $bodytargettable = "<xsl:value-of select="body/targettable"/>";
        $bodytargettablepkey = "<xsl:value-of select="body/primarykey"/>";
        $bodytargettableakey = "<xsl:value-of select="body/alternatekey"/>";
        $bodywhere = "<xsl:value-of select="body/where"/>";
        <xsl:variable name="querydoc" select="document(body/querysource)"/>
        <xsl:variable name="querytext" select="$querydoc/query/querytext"/>
        $bodyq = '<xsl:value-of select="$querytext"/>';
        $bodyqfilter = '';
        $searchq = '';
        $defaultorder = '';
        <xsl:if test="body/pageparam">
            $bodyqfilter = "<xsl:value-of select="body/pageparam"/> = ".q($keyid);
            <xsl:if test="body/altparam">
                $bodyqfilter .= " and <xsl:value-of select="body/altparam"/> = ".q($altid);
            </xsl:if>
        </xsl:if>
        <xsl:variable name="searchquerydoc" select="document(body/searchquerysource)"/>
        <xsl:variable name="searchquerytext" select="$searchquerydoc/query/querytext"/>
        $searchq = '<xsl:value-of select="$searchquerytext"/>';
        <xsl:if test="body/defaultorder">
            $defaultorder = "<xsl:value-of select="body/defaultorder"/>";
        </xsl:if>
        
        $idx = 0;
        <xsl:apply-templates select="body/fields"/>
        $bodyfieldlen = $idx;
    </xsl:if>

    <xsl:call-template name="generatelinkfunctions"/>
</xsl:template>

<xsl:template name="generatesearch">
    $title = "<xsl:value-of select="title"/>"; 
    <xsl:if test="icon">
        $icon = '<xsl:value-of select="icon"/>'; 
    </xsl:if>
    $forwardtopage = "<xsl:value-of select="redirectto"/>";
    
    $idx = 0;
    <xsl:apply-templates select="fields"/>
    $fieldlen = $idx;
</xsl:template>

<xsl:template name="generateinsert">
    $title = "<xsl:value-of select="title"/>"; 
    <xsl:if test="icon">
        $icon = '<xsl:value-of select="icon"/>'; 
    </xsl:if>

    <xsl:if test="top">
        $toptargettable = "<xsl:value-of select="top/targettable"/>";
        $toptargettablepkey = "<xsl:value-of select="top/primarykey"/>";
        $toptargettableakey = "<xsl:value-of select="top/alternatekey"/>";
        $topseedq = '';
        $topq = '';
        $topqfilter = '';
        <xsl:if test="top/seedquerysource">
            <xsl:variable name="querydoc" select="document(top/seedquerysource)"/>
            <xsl:variable name="querytext" select="$querydoc/query/querytext"/>
            $topseedq = '<xsl:value-of select="$querytext"/>';
        </xsl:if>
        <xsl:if test="top/querysource">
            <xsl:variable name="querydoc" select="document(top/querysource)"/>
            <xsl:variable name="querytext" select="$querydoc/query/querytext"/>
            $topq = '<xsl:value-of select="$querytext"/>';
        </xsl:if>
        <xsl:if test="top/pageparam">
            $topqfilter = "<xsl:value-of select="top/pageparam"/> = ".q($keyid);
            <xsl:if test="top/altparam">
                $topqfilter .= " and <xsl:value-of select="top/altparam"/> = ".q($altid);
            </xsl:if>
        </xsl:if>
        
        <xsl:call-template name="generateexportcombo"/>
        
        $idx = 0;
        <xsl:apply-templates select="top/fields"/>
        $topfieldlen = $idx;
    </xsl:if>
    
    <xsl:if test="body">
        <xsl:if test="body/@optional = 'true'">
            $bodyisoptional = true;
        </xsl:if>
        <xsl:if test="body/@noinsert = 'true'">
            $bodyisnoinsert = true;
        </xsl:if>
        <xsl:if test="body/@isdisplay = 'true'">
            $bodyisdisplay = true;
        </xsl:if>
        $bodytargettable = "<xsl:value-of select="body/targettable"/>";
        $bodytargettablefkey = "<xsl:value-of select="body/foreignkey"/>";
        $bodytargettableakey = "<xsl:value-of select="body/altforeignkey"/>";
        $bodywhere = "<xsl:value-of select="body/where"/>";
        $bodyrows = "<xsl:value-of select="body/@rows"/>";
        $bodyseedq = '';
        $bodyq = '';
        $bodyqfilter = '';
        <xsl:if test="body/seedquerysource">
            <xsl:variable name="querydoc" select="document(body/seedquerysource)"/>
            <xsl:variable name="querytext" select="$querydoc/query/querytext"/>
            $bodyseedq = '<xsl:value-of select="$querytext"/>';
        </xsl:if>
        <xsl:if test="body/querysource">
            <xsl:variable name="querydoc" select="document(body/querysource)"/>
            <xsl:variable name="querytext" select="$querydoc/query/querytext"/>
            $bodyq = '<xsl:value-of select="$querytext"/>';
        </xsl:if>
        <xsl:if test="body/pageparam">
            $bodyqfilter = "<xsl:value-of select="body/pageparam"/> = ".q($keyid);
            <xsl:if test="body/altparam">
                $bodyqfilter .= " and <xsl:value-of select="body/altparam"/> = ".q($altid);
            </xsl:if>
        </xsl:if>

        $idx = 0;
        <xsl:apply-templates select="body/fields"/>
        $bodyfieldlen = $idx;
    </xsl:if>
    <xsl:call-template name="generatelinkfunctions"/>
</xsl:template>

<xsl:template name="generateedit">
    $title = "<xsl:value-of select="title"/>"; 
    <xsl:if test="icon">
        $icon = '<xsl:value-of select="icon"/>'; 
    </xsl:if>

    $queryisupdate = true;
    <xsl:if test="top">
        $toptargettable = "<xsl:value-of select="top/targettable"/>";
        $toptargettablepkey = "<xsl:value-of select="top/primarykey"/>";
        $toptargettableakey = "<xsl:value-of select="top/alternatekey"/>";
        $topwhere = "<xsl:value-of select="top/where"/>";
        $topseedq = '';
        $topq = '';
        $topqfilter = '';
        <xsl:if test="top/seedquerysource">
            <xsl:variable name="querydoc" select="document(top/seedquerysource)"/>
            <xsl:variable name="querytext" select="$querydoc/query/querytext"/>
            $topseedq = '<xsl:value-of select="$querytext"/>';
        </xsl:if>
        <!--
        <xsl:if test="top/querysource">
            <xsl:variable name="querydoc" select="document(top/querysource)"/>
            <xsl:variable name="querytext" select="$querydoc/query/querytext"/>
            $topq = '<xsl:value-of select="$querytext"/>';
        </xsl:if>
        -->
        $topq = "SELECT * FROM $toptargettable";
        $topqfilter = "$toptargettablepkey = ".q($keyid);
        if (!empty($toptargettableakey))
          $topqfilter .= " and $toptargettableakey = ".q($altid);

        <xsl:call-template name="generateexportcombo"/>
        
        $idx = 0;
        <xsl:apply-templates select="top/fields"/>
        $topfieldlen = $idx;
    </xsl:if>
</xsl:template>

<xsl:template name="generatedelete">
    $title = "<xsl:value-of select="title"/>"; 
    <xsl:if test="icon">
        $icon = '<xsl:value-of select="icon"/>'; 
    </xsl:if>
    $forwardtopage = "<xsl:value-of select="redirectto"/>";

    <xsl:if test="top">
        $toptargettable = "<xsl:value-of select="top/targettable"/>";
        $toptargettablepkey = "<xsl:value-of select="top/primarykey"/>";
        $toptargettableakey = "<xsl:value-of select="top/alternatekey"/>";
        
        <xsl:call-template name="generateconstraint"/>

        <xsl:call-template name="generateexportcombo"/>
    </xsl:if>
    
    <xsl:if test="body">
        $bodytargettable = "<xsl:value-of select="body/targettable"/>";
        $bodytargettablefkey = "<xsl:value-of select="body/foreignkey"/>";
        $bodytargettableakey = "<xsl:value-of select="body/altforeignkey"/>";
    </xsl:if>
</xsl:template>

<xsl:template name="generateconstraint">
    <xsl:if test="top/constraints">
        $idx = 0;
        <xsl:for-each select="top/constraints/constraint">
            $idx++;
            $constraint[$idx]["table"] = "<xsl:value-of select="table"/>";
            $constraint[$idx]["field"] = "<xsl:value-of select="foreignkey"/>";
            <xsl:if test="violationmessage">
                $constraint[$idx]["message"] = "<xsl:value-of select="violationmessage"/>";
            </xsl:if>
        </xsl:for-each>
        $constraintlen = $idx;
    </xsl:if>
</xsl:template>

<xsl:template name="generateexportcombo">
    <xsl:if test="top/exportcombo">
        $idx = 0;
        <xsl:for-each select="top/exportcombo/field">
            $idx++;
            $combofield[$idx] = "<xsl:value-of select="."/>";
        </xsl:for-each>
        $combofieldlen = $idx;
    </xsl:if>
</xsl:template>

<xsl:template name="generatelinkfunctions">
    <xsl:for-each select="/page//fields/link">
        <![CDATA[
        function ]]><xsl:value-of select="@name"/><![CDATA[(&$source, &$field, $icon=false)
        {
            global $MESSAGES, $record;
            $htmlcode = "<a href=\"../meta/metapage.php?page=]]><xsl:value-of select="@target"/><![CDATA[&keyid=$record[]]><xsl:value-of select="@on"/><![CDATA[]]]><xsl:if test="@alt"><![CDATA[&altid=$record[]]><xsl:value-of select="@alt"/><![CDATA[]]]></xsl:if><![CDATA[\">";
	    if ($icon)
		$icon = member($field, "icon");
	    if (!empty($icon))
	      $htmlcode .= "<img border=0 width=32 height=32 src=\"../icon/link_$icon\" alt=\"";
	    $htmlcode .= (!myempty(member($field, "text"))?member($field, "text") : member($field, "caption")."...");
	    if (!empty($icon))
	      $htmlcode .= "\">";
	    $htmlcode .= "</a>";
            return $htmlcode;
        }
        ]]>
    </xsl:for-each>
</xsl:template>

<!-- GENERIC TEMPLATES -->

<xsl:template name="field" match="field">
    <xsl:choose>
        <xsl:when test="$pagetype='view'">
            <xsl:variable name="arrayname">
                 <xsl:choose> 
                     <xsl:when test="local-name(parent::node()/parent::node())='top'">
                         <xsl:text>topfield</xsl:text>
                     </xsl:when>
                     <xsl:when test="local-name(parent::node()/parent::node())='body'">
                         <xsl:text>bodyfield</xsl:text>
                     </xsl:when>
                 </xsl:choose>
            </xsl:variable>
            $idx++;
            $<xsl:value-of select="$arrayname"/>[$idx]["name"]    = "<xsl:value-of select="@name"/>";
            $<xsl:value-of select="$arrayname"/>[$idx]["caption"] = "<xsl:value-of select="@caption"/>";
            $<xsl:value-of select="$arrayname"/>[$idx]["domain"]  = "<xsl:value-of select="@domain"/>";
            $<xsl:value-of select="$arrayname"/>[$idx]["lang"]    = "<xsl:value-of select="@lang"/>";
            $<xsl:value-of select="$arrayname"/>[$idx]["dir"]     = "<xsl:value-of select="@dir"/>";
            $<xsl:value-of select="$arrayname"/>[$idx]["type"]    = 
               "<xsl:if test="@hidden='true'">H</xsl:if>
               ";
        </xsl:when>
        <xsl:when test="$pagetype='search'">
            <xsl:variable name="arrayname" select="'field'"/>
            $idx++;
            $<xsl:value-of select="$arrayname"/>[$idx]["name"]      = "<xsl:value-of select="@name"/>";
            $<xsl:value-of select="$arrayname"/>[$idx]["search"]    = "<xsl:value-of select="@search"/>";
            $<xsl:value-of select="$arrayname"/>[$idx]["caption"]   = "<xsl:value-of select="@caption"/>";
            $<xsl:value-of select="$arrayname"/>[$idx]["domain"]    = "<xsl:value-of select="@domain"/>";
            $<xsl:value-of select="$arrayname"/>[$idx]["example"]   = "<xsl:value-of select="@example"/>";
            $<xsl:value-of select="$arrayname"/>[$idx]["note"]      = "<xsl:value-of select="@note"/>";
            $<xsl:value-of select="$arrayname"/>[$idx]["size"]      = "<xsl:value-of select="@size"/>";
            $<xsl:value-of select="$arrayname"/>[$idx]["maxlength"] = "<xsl:value-of select="@maxlength"/>";
            $<xsl:value-of select="$arrayname"/>[$idx]["lang"]      = "<xsl:value-of select="@lang"/>";
            $<xsl:value-of select="$arrayname"/>[$idx]["dir"]       = "<xsl:value-of select="@dir"/>";
            $<xsl:value-of select="$arrayname"/>[$idx]["type"]      = 
               "<xsl:if test="@type='exact'">S</xsl:if>
                <xsl:if test="@type='partial'">E</xsl:if>
                <xsl:if test="@type='range'">D</xsl:if>
                <xsl:if test="@type='cidr'">@</xsl:if>
               ";
        </xsl:when>
        <xsl:when test="$pagetype='insert'">
            <xsl:variable name="arrayname">
                 <xsl:choose> 
                     <xsl:when test="local-name(parent::node()/parent::node())='top'">
                         <xsl:text>topfield</xsl:text>
                     </xsl:when>
                     <xsl:when test="local-name(parent::node()/parent::node())='body'">
                         <xsl:text>bodyfield</xsl:text>
                     </xsl:when>
                 </xsl:choose>
            </xsl:variable>
            $idx++;
            $<xsl:value-of select="$arrayname"/>[$idx]["name"]          = "<xsl:value-of select="@name"/>";
            $<xsl:value-of select="$arrayname"/>[$idx]["caption"]       = "<xsl:value-of select="@caption"/>";
            $<xsl:value-of select="$arrayname"/>[$idx]["domain"]        = "<xsl:value-of select="@domain"/>";
            $<xsl:value-of select="$arrayname"/>[$idx]["example"]       = "<xsl:value-of select="@example"/>";
            $<xsl:value-of select="$arrayname"/>[$idx]["note"]      = "<xsl:value-of select="@note"/>";
            <xsl:if test="@size">
                $<xsl:value-of select="$arrayname"/>[$idx]["size"]      = "<xsl:value-of select="@size"/>";
            </xsl:if>
            <xsl:if test="@maxlength">
                $<xsl:value-of select="$arrayname"/>[$idx]["maxlength"] = "<xsl:value-of select="@maxlength"/>";
            </xsl:if>
            <xsl:if test="@lang">
                $<xsl:value-of select="$arrayname"/>[$idx]["lang"]      = "<xsl:value-of select="@lang"/>";
            </xsl:if>
            <xsl:if test="@dir">
                $<xsl:value-of select="$arrayname"/>[$idx]["dir"]      = "<xsl:value-of select="@dir"/>";
            </xsl:if>
            $<xsl:value-of select="$arrayname"/>[$idx]["type"]    = "
            <xsl:choose>
                <xsl:when test="@type='standard'">S</xsl:when>
                <xsl:when test="@type='seed'">I</xsl:when>
                <xsl:when test="@type='text'">B</xsl:when>
                <xsl:when test="@type='combo'">M</xsl:when>
                <xsl:when test="@type='constant'">C</xsl:when>
                <xsl:when test="@type='password'">W</xsl:when>
                <xsl:when test="@type='display'">D</xsl:when>
                <xsl:when test="@type='displayseed'">DI</xsl:when>
                <xsl:when test="@type='comboseed'">i</xsl:when>
            </xsl:choose>
            <xsl:if test="@hidden='true'">H</xsl:if>
            <xsl:if test="@optional='true'">N</xsl:if>
            <xsl:if test="@ignore='true'">X</xsl:if>
            <xsl:if test="@assert='true'">V</xsl:if>
            ";
            <xsl:if test="@source">
                $<xsl:value-of select="$arrayname"/>[$idx]["source"]    = "<xsl:value-of select="@source"/>";
            </xsl:if>
            <xsl:if test="@default">
                $<xsl:value-of select="$arrayname"/>[$idx]["default"]   = "<xsl:value-of select="@default"/>";
            </xsl:if>
            <xsl:if test="@value">
                <xsl:choose>
                    <xsl:when test="@value='pageparam'">
                        $<xsl:value-of select="$arrayname"/>[$idx]["value"]    = "$keyid";
                    </xsl:when>
                    <xsl:when test="@value='altparam'">
                        $<xsl:value-of select="$arrayname"/>[$idx]["value"]    = "$altid";
                    </xsl:when>
                    <xsl:otherwise>
                        $<xsl:value-of select="$arrayname"/>[$idx]["value"]    = "<xsl:value-of select="@value"/>";
                    </xsl:otherwise>
                </xsl:choose>   
            </xsl:if>
        </xsl:when>
        <xsl:when test="$pagetype='edit'">
            <xsl:variable name="arrayname">
                 <xsl:choose> 
                     <xsl:when test="local-name(parent::node()/parent::node())='top'">
                         <xsl:text>topfield</xsl:text>
                     </xsl:when>
                     <xsl:when test="local-name(parent::node()/parent::node())='body'">
                         <xsl:text>bodyfield</xsl:text>
                     </xsl:when>
                 </xsl:choose>
            </xsl:variable>
            $idx++;
            $<xsl:value-of select="$arrayname"/>[$idx]["name"]    = "<xsl:value-of select="@name"/>";
            $<xsl:value-of select="$arrayname"/>[$idx]["caption"] = "<xsl:value-of select="@caption"/>";
            $<xsl:value-of select="$arrayname"/>[$idx]["domain"]  = "<xsl:value-of select="@domain"/>";
            $<xsl:value-of select="$arrayname"/>[$idx]["example"] = "<xsl:value-of select="@example"/>";
            $<xsl:value-of select="$arrayname"/>[$idx]["note"]    = "<xsl:value-of select="@note"/>";
            <xsl:if test="@size">
                $<xsl:value-of select="$arrayname"/>[$idx]["size"]      = "<xsl:value-of select="@size"/>";
            </xsl:if>
            <xsl:if test="@maxlength">
                $<xsl:value-of select="$arrayname"/>[$idx]["maxlength"] = "<xsl:value-of select="@maxlength"/>";
            </xsl:if>
            <xsl:if test="@lang">
                $<xsl:value-of select="$arrayname"/>[$idx]["lang"]      = "<xsl:value-of select="@lang"/>";
            </xsl:if>
            <xsl:if test="@dir">
                $<xsl:value-of select="$arrayname"/>[$idx]["dir"]      = "<xsl:value-of select="@dir"/>";
            </xsl:if>
            $<xsl:value-of select="$arrayname"/>[$idx]["type"]    = "
            <xsl:choose>
                <xsl:when test="not(@type)">E</xsl:when>
                <xsl:when test="@type='standard'">E</xsl:when>
                <xsl:when test="@type='seed'">I</xsl:when>
                <xsl:when test="@type='text'">EB</xsl:when>
                <xsl:when test="@type='combo'">EM</xsl:when>
                <xsl:when test="@type='constant'">C</xsl:when>
                <xsl:when test="@type='password'">W</xsl:when>
                <xsl:when test="@type='display'">D</xsl:when>
                <xsl:when test="@type='displayseed'">DI</xsl:when>
                <xsl:when test="@type='comboseed'">i</xsl:when>
            </xsl:choose>
            <xsl:if test="@hidden='true'">H</xsl:if>
            <xsl:if test="@optional='true'">N</xsl:if>
            <xsl:if test="@ignore='true'">X</xsl:if>
            <xsl:if test="@assert='true'">V</xsl:if>
            ";
            <xsl:if test="not(@type) or
                          @type='standard' or
                          @type='text' or
                          @type='combo'">
                $<xsl:value-of select="$arrayname"/>[$idx]["value"]    = "<xsl:value-of select="@name"/>";
            </xsl:if>
            <xsl:if test="@source">
                $<xsl:value-of select="$arrayname"/>[$idx]["source"]    = "<xsl:value-of select="@source"/>";
            </xsl:if>
            <xsl:if test="@value">
                $<xsl:value-of select="$arrayname"/>[$idx]["value"]    = "<xsl:value-of select="@value"/>";
            </xsl:if>
        </xsl:when>
    </xsl:choose>
    <xsl:call-template name="defaultdomain"/>
</xsl:template>

<xsl:template match="link">
    <xsl:variable name="arrayname">
         <xsl:choose> 
             <xsl:when test="local-name(parent::node()/parent::node())='top'">
                 <xsl:text>topfield</xsl:text>
             </xsl:when>
             <xsl:when test="local-name(parent::node()/parent::node())='body'">
                 <xsl:text>bodyfield</xsl:text>
             </xsl:when>
         </xsl:choose>
    </xsl:variable>
    $idx++;
    $<xsl:value-of select="$arrayname"/>[$idx]["type"]    = "YOl";
    $<xsl:value-of select="$arrayname"/>[$idx]["name"]    = "<xsl:value-of select="@name"/>";
    $<xsl:value-of select="$arrayname"/>[$idx]["on"]    = "<xsl:value-of select="@on"/>";
    $<xsl:value-of select="$arrayname"/>[$idx]["alt"]     = "<xsl:value-of select="@alt"/>";
    $<xsl:value-of select="$arrayname"/>[$idx]["text"]    = "<xsl:value-of select="@text"/>";
    $<xsl:value-of select="$arrayname"/>[$idx]["caption"] = "<xsl:value-of select="@caption"/>";
    $<xsl:value-of select="$arrayname"/>[$idx]["func"]    = "<xsl:value-of select="@name"/>";
    $<xsl:value-of select="$arrayname"/>[$idx]["domain"]  = "<xsl:value-of select="@domain"/>";
    <xsl:call-template name="defaultdomain"/>
</xsl:template>

<xsl:template match="cfield">
    <xsl:call-template name="field"/>
    <xsl:variable name="arrayname">
         <xsl:choose> 
             <xsl:when test="local-name(parent::node()/parent::node())='top'">
                 <xsl:text>topfield</xsl:text>
             </xsl:when>
             <xsl:when test="local-name(parent::node()/parent::node())='body'">
                 <xsl:text>bodyfield</xsl:text>
             </xsl:when>
         </xsl:choose>
    </xsl:variable>
    $<xsl:value-of select="$arrayname"/>[$idx]["type"]    .= "YO";
    $<xsl:value-of select="$arrayname"/>[$idx]["func"]    = "<xsl:value-of select="@code"/>";
</xsl:template>

<xsl:template name="generateaccess">
  $pageaccess= "<xsl:value-of select="$pageaccess"/>";
  $earlydb = true;
  include_once ("../inc/auth.php");
  if (function_exists('access')) {
    if (!access($dummys, $dummyf)) {
      include_once BASE."/inc/functions.php";
      include_once BASE."/meta/lang/default.php";
      $MESSAGE = formaterror($MESSAGES["insufficientrights"]);
      $EXIT = 1;
    }
  } else
    $earlydb = false;
</xsl:template>

<xsl:template name="generateonenter">
  $haserror = false;
  if (function_exists('onenter')) {
      $haserror = onenter();
  }
</xsl:template>

<xsl:template name="generateonsuccess">
    $follow = "<xsl:value-of select="onsuccess"/>";
    $followkeyid    = "";
    <xsl:if test="onsuccess/@on">
      $followkeyid    = "<xsl:value-of select="onsuccess/@on"/>";
    </xsl:if>
    $followaltid    = "";
    <xsl:if test="onsuccess/@alt">
        $followaltid    = "<xsl:value-of select="onsuccess/@alt"/>";
    </xsl:if>
</xsl:template>

<xsl:template match="hr">
    <xsl:variable name="arrayname">
         <xsl:choose> 
             <xsl:when test="local-name(parent::node()/parent::node())='top'">
                 <xsl:text>topfield</xsl:text>
             </xsl:when>
             <xsl:when test="local-name(parent::node()/parent::node())='body'">
                 <xsl:text>bodyfield</xsl:text>
             </xsl:when>
             <xsl:otherwise>
                 <xsl:text>field</xsl:text>
             </xsl:otherwise>
         </xsl:choose>
    </xsl:variable>
    $idx++;
    $<xsl:value-of select="$arrayname"/>[$idx]["type"]    = "R";
</xsl:template>

<xsl:template match="vr">
    <xsl:variable name="arrayname">
         <xsl:choose> 
             <xsl:when test="local-name(parent::node()/parent::node())='top'">
                 <xsl:text>topfield</xsl:text>
             </xsl:when>
             <xsl:when test="local-name(parent::node()/parent::node())='body'">
                 <xsl:text>bodyfield</xsl:text>
             </xsl:when>
             <xsl:otherwise>
                 <xsl:text>field</xsl:text>
             </xsl:otherwise>
         </xsl:choose>
    </xsl:variable>
    $idx++;
    $<xsl:value-of select="$arrayname"/>[$idx]["type"]    = "T";
</xsl:template>

<xsl:template match="code">
    function <xsl:value-of select="@name"/>
    (
    <xsl:if test="not(@name = 'onenter' or @name='onload' or @name='onsubmit' or @name='onsuccess')">
        <![CDATA[&$source, &$field]]>
    </xsl:if>
    )
    {
        global $db, $MESSAGES, $DOMAINS, $S,
		$record, $keyid, $altid, $pageaccess,
		$bodyrows, $filledbodyrows,
		$topfield, $topfieldlen, $toperrorfield,
		$bodyfield, $bodyfieldlen, $bodyerrorfield;
        
        <xsl:apply-templates/>
    }
</xsl:template>

<xsl:template name="defaultdomain">
    <xsl:variable name="arrayname">
         <xsl:choose> 
             <xsl:when test="$pagetype='search'">
                 <xsl:text>field</xsl:text>
             </xsl:when>
             <xsl:when test="local-name(parent::node()/parent::node())='top'">
                 <xsl:text>topfield</xsl:text>
             </xsl:when>
             <xsl:when test="local-name(parent::node()/parent::node())='body'">
                 <xsl:text>bodyfield</xsl:text>
             </xsl:when>
         </xsl:choose>
    </xsl:variable>
    if (myempty($<xsl:value-of select="$arrayname"/>[$idx]["domain"]))
      $<xsl:value-of select="$arrayname"/>[$idx]["domain"] = $<xsl:value-of select="$arrayname"/>[$idx]["name"];
</xsl:template>

</xsl:stylesheet>
